@@ -230,7 +230,16 @@ pub enum RedisCacheError {
 
 #[derive(serde::Serialize, serde::Deserialize)]
 struct CachedRedisValue<V> {
-    value: V,
+    pub(crate) value: V,
+    pub(crate) version: Option<u64>,
+}
+impl<V> CachedRedisValue<V> {
+    fn new(value: V) -> Self {
+        Self {
+            value,
+            version: Some(1),
+        }
+    }
 }
 
 impl<'de, K, V> IOCached<K, V> for RedisCache<K, V>
@@ -270,7 +279,7 @@ where
         let mut pipe = redis::pipe();
         let key = self.generate_key(&key);
 
-        let val = CachedRedisValue { value: val };
+        let val = CachedRedisValue::new(val);
         pipe.get(key.clone());
         pipe.set_ex::<String, String>(
             key,
@@ -517,7 +526,7 @@ mod async_redis {
             let mut pipe = redis::pipe();
             let key = self.generate_key(&key);
 
-            let val = CachedRedisValue { value: val };
+            let val = CachedRedisValue::new(val);
             pipe.get(key.clone());
             pipe.set_ex::<String, String>(
                 key,
@@ -598,7 +607,7 @@ mod async_redis {
                 .as_millis()
         }
 
-        #[async_std::test]
+        #[tokio::test]
         async fn test_async_redis_cache() {
             let mut c: AsyncRedisCache<u32, u32> =
                 AsyncRedisCache::new(format!("{}:async-redis-cache-test", now_millis()), 2)
